require_relative "../../../../test_helper"

class ETest < MTest
  def test_e
    assert_equal 1, 1
  end
end
